compute_plugin_hash

Function compute_plugin_hash 

pub fn compute_plugin_hash(files: &HashMap<String, String>) -> String
Compute composite hash of all files in a plugin Files are sorted by name for deterministic hashing